==> deepin-screensaver_5.0.18.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="142"/>
        <source>Restore Defaults</source>
        <translation>恢复默认</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation>选择图片路径</translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation>请选择图片路径</translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation>自定义屏保</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation>随机轮播</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation>轮播设置</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="225"/>
        <source>Picture path</source>
        <translation>选择图片路径</translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="143"/>
        <source>Picture not found</source>
        <translation>图片不见了</translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation>轮播间隔（秒）</translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation>数值范围</translation>
    </message>
</context>
</TS>

==> deepin-screensaver_5.0.20.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="145"/>
        <source>Restore Defaults</source>
        <translation>恢复默认</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="37"/>
        <location filename="../src/main.cpp" line="38"/>
        <source>deepin-screensaver</source>
        <translation>自定义屏保</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation>选择图片路径</translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation>请选择图片路径</translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation>自定义屏保</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation>随机轮播</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation>轮播设置</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="228"/>
        <source>Picture path</source>
        <translation>选择图片路径</translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="142"/>
        <source>Please select a valid image path in the Custom Screensaver &quot;Screensaver Setting&quot;.</source>
        <translation>请在自定义屏保“屏保设置”中选择有效的图片路径。</translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation>轮播间隔（秒）</translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation>数值范围</translation>
    </message>
</context>
</TS>
